%define oname	GeoGebra-Unixlike-Installer

Name:		geogebra
Version:	4.2.60.0
Release:	%mkrel 1
Summary:	Free mathematics software for learning and teaching
Group:		Sciences/Mathematics
License:	GPLv2+
Url:		http://www.geogebra.org
# wget http://www.geogebra.org/download/?os=unix -O %%{oname}-%%{version}.tar.gz
Source:		%{oname}-%{version}.tar.gz  
BuildArch:	noarch
BuildRequires:	desktop-file-utils

Requires:	java-1.7.0-openjdk


%description
This package provides GeoGebra.

GeoGebra is free dynamic mathematics software for all
levels of education that joins geometry, algebra, tables, graphing, statistics
and calculus in one easy-to-use package. It has received several educational
software awards in Europe and the USA.

Quick Facts:

- Graphics, algebra and tables are connected and fully dynamic
- Easy-to-use interface, yet many powerful features 
- Authoring tool to create interactive learning materials as web pages 
- Available in many languages for our millions of users around the world 
- Free and open source software


Authors:
--------
    Markus Hohenwarter (Austria & USA): Project leader since 2001
    Michael Borcherds (UK): Lead Developer since 2007
    Yves Kreis (Luxembourg): Developer since 2005

%prep
%setup -q -n %{name}-%{version}

mv _license.txt COPYING
chmod 0644 geogebra.desktop

%build

%install
# .jar-repertory
mkdir -p %{buildroot}%{_javadir}/%{name} 
cp *.jar %{buildroot}%{_javadir}/%{name}

mkdir -p %{buildroot}%{_datadir}/mime/packages
cp geogebra.xml %{buildroot}%{_datadir}/mime/packages/%{name}.xml

# icons-repertory
for SIZE in 16x16 22x22 32x32 48x48 64x64 128x128 256x256 scalable; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/$SIZE/apps %{buildroot}%{_iconsdir}/hicolor/$SIZE/mimetypes
  cp icons/hicolor/$SIZE/apps/geogebra.* %{buildroot}%{_iconsdir}/hicolor/$SIZE/apps
  cp icons/hicolor/$SIZE/mimetypes/application-vnd.geogebra.file.* %{buildroot}%{_iconsdir}/hicolor/$SIZE/mimetypes
  cp icons/hicolor/$SIZE/mimetypes/application-vnd.geogebra.tool.* %{buildroot}%{_iconsdir}/hicolor/$SIZE/mimetypes
done

# menu-entry
mkdir -p %{buildroot}%{_datadir}/applications 
desktop-file-install --mode=0644 --dir=%{buildroot}%{_datadir}/applications %{name}.desktop

# startscript
mkdir -p %{buildroot}%{_bindir}
cat > %{buildroot}%{_bindir}/%{name} << EOF
#!/bin/bash
# simple script to start GeoGebra
func_usage()
{
cat << _USAGE
Usage: %{name} [Java-options] [GeoGebra-options] [FILE]

GeoGebra - Dynamic mathematics software

Java options:
  -Xms<size>				Set initial Java heap size
  -Xmx<size>				Set maximum Java heap size

GeoGebra options:
  --help				Show this help message
  --language=<iso_code>			Set language using locale code, e.g. en, de_AT
  --showAlgebraInput=<boolean>		Show/hide algebra input field
  --showAlgebraWindow=<boolean>		Show/hide algebra window
  --showSpreadsheet=<boolean>		Show/hide spreadsheet
  --fontSize=<number>			Set default font size
  --showSplash=<boolean>		Enable/disable the splash screen
  --enableUndo=<boolean>		Enable/disable Undo
_USAGE
}
# JAVACMD
if [ -z "\$JAVACMD" ]; then
	JAVACMD=java
fi
# check for option --help and pass memory options to Java, others to GeoGebra
for i in "\$@"; do
    case "\$i" in
    --help | --hel | --he | --h )
	func_usage; exit 0 ;;
    esac
    if [ \$(expr match "\$i" '.*-Xm') -ne 0 ]; then
	if [ -z "\$JAVA_OPTS" ]; then
	    JAVA_OPTS="\$i"
	else
	    JAVA_OPTS="\$JAVA_OPTS \$i"
	fi
	shift \$((1))
    else
	if [ \$(expr match "\$i" '.*--') -ne 0 ]; then
	    if [ -z "\$GG_OPTS" ]; then
		GG_OPTS="\$i"
	    else
		GG_OPTS="\$GG_OPTS \$i"
	    fi
	    shift \$((1))
	fi
    fi
done
# if memory not set, change to GeoGebra defaults
if [ \$(expr match "\$JAVA_OPTS" '.*-Xmx') -eq 0 ]; then
    JAVA_OPTS="\$JAVA_OPTS -Xmx512m"
fi
if [ \$(expr match "\$JAVA_OPTS" '.*-Xms') -eq 0 ]; then
    JAVA_OPTS="\$JAVA_OPTS -Xms32m"
fi
# run
exec \$JAVACMD \$JAVA_OPTS -jar %{_javadir}/%{name}/geogebra.jar \$GG_OPTS "\$@"
EOF

chmod 0755 %{buildroot}%{_bindir}/%{name}

%files
%doc COPYING README
%{_bindir}/%{name}
%{_javadir}/%{name}/
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/*/*/*/*.png
%{_iconsdir}/*/*/*/*.svgz


%changelog
* Sat Oct 05 2013 david.david (MLO Team) <david.david> 4.2.60.0-1.mga3
+ new version: 4.2.60.0
- fix correct repertory for jar files '%%{_javadir}' 

* Sat Aug 10 2013 david.david (MLO Team) <david.david> 4.2.55.0-1.mga3
+ new version: 4.2.55.0

* Fri Jul 05 2013 david.david (MLO Team) <david.david> 4.2.51.0-1.mga3
+ new version: 4.2.51.0
- clean spec file

* Thu May 23 2013 david.david (MLO Team) <david.david> 4.2.41.0-1.mga3
+ New version: 4.2.41.0
- adapted spec for new version

* Thu May 23 2013 Adrien.D (MLO Team) <adrien.d> 3.2.47.0-1.mga3
+ Rebuild package for Mageia 3 (Core)
- imported package from Mandriva
- adapted for Mageia
- clean Spec File
